@@ -475,9 +475,9 @@ def file_path(value, **kwargs):
     value = re.sub(regex, path_sep, value)
     # only clean the path for non urls
     if len(value) > 250:
-        print(f"clean path: ",value)
+        # print(f"clean path: ",value)
         value = clean_path(value)
-        print(f"clean path: ",value)
+        # print(f"clean path: ",value)
     if escape_spaces:
         path_array = value.split(os.path.sep)
         new_path_array = []
